@@ -111,8 +111,6 @@ class GetDataCustConAddRequestSerializer(serializers.Serializer):
 class GetActiveLoanByAppIdsRequestSerializer(serializers.Serializer):
     app_ids = serializers.CharField(required=True)
 
-class GetRegisAndActHiFromDWHRequestSerializer(serializers.Serializer):
-    appId = serializers.CharField(required=True)
 
 class FraudSerializer(serializers.Serializer):
     """
@@ -136,20 +134,13 @@ class FraudSerializer(serializers.Serializer):
     applicationID = serializers.CharField(required=False, allow_blank=True, allow_null=True)
     bankAccount = serializers.CharField(required=False, allow_blank=True, allow_null=True)
     nationalId = serializers.CharField(required=False, allow_blank=True, allow_null=True)
-    personId = serializers.CharField(required=False, allow_blank=True, allow_null=True)
-    productId = serializers.CharField(required=False, allow_blank=True, allow_null=True)
-    productCode = serializers.CharField(required=False, allow_blank=True, allow_null=True)
 
 class GetBlacklistedAccountsRequestSerializer(serializers.Serializer):
     bank_account = serializers.CharField(required=True)
 
 
 class GetAMLCheckServiceRequestSerializer(serializers.Serializer):
-    PERSON_ID = serializers.CharField()
+    PERSON_ID = serializers.CharField(required=False, allow_null=True, allow_blank=True)
     FULL_NAME = serializers.CharField()
     ID_NO = serializers.CharField()
-    DOB = serializers.CharField()
-
-
-class CheckBlackListPhoneNumberRequestSerializer(serializers.Serializer):
-    phoneNumber = serializers.CharField()
\ No newline at end of file
+    DOB = serializers.CharField()
\ No newline at end of file
